@@ -35,6 +35,7 @@ class SocketEvents(str, Enum):
     ROOM_JOINED = "room_joined"
     ROOM_LEFT = "room_left"
     SET_NEW_DEVICE_NR = "set_new_device_nr"
+    TIMER = "timer"
 
 
 class DataType(str, Enum):
@@ -89,6 +90,11 @@ CssColorType = Union[int, str, RgbColor, Tuple[R, G, B, A], List[float], List[Un
 BaseColor = Union[str, RgbColor]
 
 
+@dataclass
+class TimerMsg:
+    time: float = 0
+
+
 @dataclass
 class DeliveryOptions:
     broadcast: bool = False
